@@ -7,7 +7,7 @@ from PIL import Image
 
 from codeboxapi import CodeBox
 
-codebox = CodeBox(api_key="sk-427ed7bc1c420490ef4bfa42369fa41d26e864")
+codebox = CodeBox(api_key="local")
 
 # download the iris dataset
 iris_csv_bytes = httpx.get(
